@@ -84,15 +84,19 @@ def _check_error(r: requests.models.Response) -> Union[dict, list]:
     raise _create_exception(parsed_response, r.status_code, reason, r.url)
 
 
-def all_references(base_url: str, auth: Optional[AuthBase], ssl_verify: bool = True) -> dict:
+def all_references(base_url: str, auth: Optional[AuthBase], ssl_verify: bool = True, fetch_additional_info: bool = False) -> dict:
     """Fetch all known references.
 
     :param base_url: base Nessie url
     :param auth: Authentication settings
     :param ssl_verify: ignore ssl errors if False
+    :param fetch_additional_info: indicates whether additional metadata should be fetched
     :return: json list of Nessie references
     """
-    return cast(dict, _get(base_url + "/trees", auth, ssl_verify=ssl_verify))
+    params = {}
+    if fetch_additional_info:
+        params["fetchAdditionalInfo"] = "true"
+    return cast(dict, _get(base_url + "/trees", auth, ssl_verify=ssl_verify, params=params))
 
 
 def get_reference(base_url: str, auth: Optional[AuthBase], ref: str, ssl_verify: bool = True) -> dict:
@@ -202,7 +206,7 @@ def list_logs(
     ssl_verify: bool = True,
     max_records: Optional[int] = None,
     fetch_additional_info: bool = False,
-    **filtering_args: Any
+    **filtering_args: Any,
 ) -> dict:
     """Fetch a list of all logs from a known starting reference.
 
@@ -336,3 +340,16 @@ def commit(
     url = "/trees/branch/{}/commit".format(branch)
     params = {"expectedHash": expected_hash}
     return cast(dict, _post(base_url + url, auth, json=operations, ssl_verify=ssl_verify, params=params))
+
+
+def get_diff(base_url: str, auth: Optional[AuthBase], from_ref: str, to_ref: str, ssl_verify: bool = True) -> dict:
+    """Fetch the diff for two given references.
+
+    :param base_url: base Nessie url
+    :param auth: Authentication settings
+    :param from_ref: the starting ref for the diff
+    :param to_ref:  the ending ref for the diff
+    :param ssl_verify: ignore ssl errors if False
+    :return: json dict of a Diff
+    """
+    return cast(dict, _get(f"{base_url}/diffs/{from_ref}...{to_ref}", auth, ssl_verify=ssl_verify))
