@@ -30,6 +30,7 @@ from pynessie.model import CommitMeta
 from pynessie.model import CommitMetaSchema
 from pynessie.model import ContentKey
 from pynessie.model import ContentSchema
+from pynessie.model import DiffResponseSchema
 from pynessie.model import EntrySchema
 from pynessie.model import IcebergTable
 from pynessie.model import LogEntry
@@ -183,6 +184,19 @@ def test_branch() -> None:
     assert_that(references.name).is_equal_to("etl")
     references = simplejson.loads(execute_cli_command(["--json", "branch", "-l", "foo"]))
     assert len(references) == 0
+
+    table = _new_table("test_branch_metadata")
+    make_commit("test.branch.metadata", table, "dev", author="nessie_user1")
+
+    branch = ReferenceSchema().loads(execute_cli_command(["--json", "branch", "-l", "dev", "--extended"]))
+    ref_metadata = branch.metadata
+    assert_that(ref_metadata).is_not_none()
+    assert_that(ref_metadata.num_commits_ahead).is_equal_to(1)
+    assert_that(ref_metadata.num_commits_behind).is_equal_to(0)
+    assert_that(ref_metadata.num_total_commits).is_equal_to(1)
+    assert_that(ref_metadata.common_ancestor_hash).is_not_empty()
+    assert_that(ref_metadata.commit_meta_of_head).is_not_none()
+
     execute_cli_command(["branch", "-d", "etl"])
     execute_cli_command(["branch", "-d", "dev"])
     references = ReferenceSchema().loads(execute_cli_command(["--json", "branch"]), many=True)
@@ -213,6 +227,19 @@ def test_tag() -> None:
     branches = {i.name: i.hash_ for i in ReferenceSchema().loads(execute_cli_command(["--json", "branch"]), many=True)}
     assert tags["v1.0"] == branches["main"]
 
+    execute_cli_command(["branch", "metadata_branch", "main"])
+    table = _new_table("test_tag_metadata")
+    make_commit("test.tag.metadata", table, "metadata_branch", author="nessie_user1")
+    execute_cli_command(["tag", "metadata_tag", "metadata_branch"])
+    ref = ReferenceSchema().loads(execute_cli_command(["--json", "tag", "-l", "metadata_tag", "--extended"]))
+    ref_metadata = ref.metadata
+    assert_that(ref_metadata).is_not_none()
+    assert_that(ref_metadata.num_commits_ahead).is_none()
+    assert_that(ref_metadata.num_commits_behind).is_none()
+    assert_that(ref_metadata.num_total_commits).is_equal_to(1)
+    assert_that(ref_metadata.common_ancestor_hash).is_none()
+    assert_that(ref_metadata.commit_meta_of_head).is_not_none()
+
 
 @pytest.mark.vcr
 def test_assign() -> None:
@@ -259,3 +286,23 @@ def test_transplant() -> None:
 
     logs = simplejson.loads(execute_cli_command(["--json", "log"]))
     assert len(logs) == 2  # two commits were transplanted into an empty `main`
+
+
+@pytest.mark.vcr
+def test_diff() -> None:
+    """Test log and log filtering."""
+    diff = DiffResponseSchema().loads(execute_cli_command(["--json", "diff", "main", "main"]))
+    assert_that(diff).is_not_none()
+    assert_that(diff.diffs).is_empty()
+    branch = "dev_test_diff"
+    execute_cli_command(["branch", branch])
+    table = _new_table(branch)
+    content_key = "diff.foo.dev"
+    make_commit(content_key, table, branch, author="nessie_user1")
+    diff = DiffResponseSchema().loads(execute_cli_command(["--json", "diff", "main", branch]))
+    assert_that(diff).is_not_none()
+    assert_that(diff.diffs).is_length(1)
+    diff_entry = diff.diffs[0]
+    assert_that(diff_entry.content_key).is_equal_to(ContentKey.from_path_string(content_key))
+    assert_that(diff_entry.from_content).is_none()
+    assert_that(diff_entry.to_content).is_equal_to(table)
